@@ -1,11 +1,15 @@
 import csv
 import torch
 import sys
-import SentenceTokenizer as st
 from torch.utils.data import DataLoader, Dataset, IterableDataset
+from take_text_preprocess.presentation import pre_process
+
+from .process_option import PREPROCESS_OPTION
+
 
 class MultiSentWordDataset(IterableDataset):
-    def __init__(self, path, label_column, encoding, separator, use_pre_processing = False):
+    def __init__(self, path, label_column, encoding, separator,
+                 use_pre_processing=False):
         self.__set_file_iterable(path, encoding, separator)
         self.__set_process(use_pre_processing)
         self.line_mapper = self.line_mapper_training if label_column else self.line_mapper_predicting
@@ -17,7 +21,6 @@ class MultiSentWordDataset(IterableDataset):
 
     def __set_process(self, use_pre_processing):
         if use_pre_processing:
-            self.tokenizer = st.SentenceTokenizer()
             self.process = self.pre_process  
         else:
             self.process = self.split_sentence
@@ -31,10 +34,12 @@ class MultiSentWordDataset(IterableDataset):
     def line_mapper_predicting(self, line):
         return [self.process(line[0])]
 
-    def pre_process(self, sentence):
-        return self.tokenizer.process_message(sentence).split()
-    
-    def split_sentence(self, sentence): 
+    @staticmethod
+    def pre_process(sentence):
+        return pre_process(sentence, PREPROCESS_OPTION).split()
+
+    @staticmethod
+    def split_sentence(sentence):
         return sentence.split()   
 
     def __iter__(self):
@@ -44,22 +49,26 @@ class MultiSentWordDataset(IterableDataset):
     def __len__(self):
         return 1
 
+
 class MultiSentWordBatchDataset(Dataset):
     def __init__(self, sentences):
         self.sentences = sentences
-        self.tokenizer = st.SentenceTokenizer()
 
-    def pre_process(self, sentence):
-        return self.tokenizer.process_message(sentence).split()
+    @staticmethod
+    def pre_process(sentence):
+        return pre_process(sentence, PREPROCESS_OPTION).split()
 
     def __len__(self):
         return len(self.sentences)
 
     def __getitem__(self, idx):
-        return [self.pre_process(self.sentences[idx]['sentence']), int(self.sentences[idx]['id'])]
-    
+        return [self.pre_process(self.sentences[idx]['sentence']),
+                int(self.sentences[idx]['id'])]
+
+
 class MultiSentWordDataLoader(DataLoader):
-    def __init__(self, dataset, vocabs, pad_string, unk_string, tensor_lens=True, use_index=False, **kwargs):
+    def __init__(self, dataset, vocabs, pad_string, unk_string,
+                 tensor_lens=True, use_index=False, **kwargs):
         super(MultiSentWordDataLoader, self).__init__(
             dataset=dataset,
             collate_fn=self.collate_fn,
@@ -74,7 +83,9 @@ class MultiSentWordDataLoader(DataLoader):
         self.use_index = use_index
 
     def unlexicalize(self, sentence):
-        return [self.sentences_vocab.f2i[word] if word in self.sentences_vocab else self.sentences_vocab.f2i[self.unk_string] for word in sentence]
+        return [self.sentences_vocab.f2i[word] if word in self.sentences_vocab
+                else self.sentences_vocab.f2i[self.unk_string] for word in
+                sentence]
 
     def pad(self, sentence):
         return sentence + [self.sentences_vocab.f2i[self.pad_string]] * (self.max_len - len(sentence))
